@@ -1,4 +1,4 @@
-/* $Id: gweather-pref.c,v 1.98 2006/01/30 01:06:07 philipl Exp $ */
+/* $Id: gweather-pref.c,v 1.100 2006/02/11 23:57:28 philipl Exp $ */
 
 /*
  *  Papadimitriou Spiros <spapadim+@cs.cmu.edu>
@@ -320,13 +320,15 @@ auto_update_toggled (GtkToggleButton *button, GWeatherPref *pref)
     if (gw_applet->suncalc_timeout_tag > 0)
         gtk_timeout_remove(gw_applet->suncalc_timeout_tag);
     if (gw_applet->gweather_pref.update_enabled) {
-        gw_applet->timeout_tag =  
-        	gtk_timeout_add (gw_applet->gweather_pref.update_interval * 1000,
-                                 timeout_cb, pref);
+        gw_applet->timeout_tag = gtk_timeout_add (
+				gw_applet->gweather_pref.update_interval * 1000,
+				timeout_cb, gw_applet);
 	nxtSunEvent = weather_info_next_sun_event(gw_applet->gweather_info);
 	if (nxtSunEvent >= 0)
-	    gw_applet->suncalc_timeout_tag = gtk_timeout_add (nxtSunEvent * 1000,
-							      suncalc_timeout_cb, pref);
+	    gw_applet->suncalc_timeout_tag = gtk_timeout_add (
+	    						nxtSunEvent * 1000,
+							suncalc_timeout_cb,
+							gw_applet);
     }
 }
 
@@ -518,7 +520,7 @@ update_interval_changed (GtkSpinButton *button, GWeatherPref *pref)
     if (gw_applet->gweather_pref.update_enabled)
         gw_applet->timeout_tag =  
         	gtk_timeout_add (gw_applet->gweather_pref.update_interval * 1000,
-                                 timeout_cb, pref);
+                                 timeout_cb, gw_applet);
 }
 
 static gboolean
