@@ -18,11 +18,12 @@
 
 #include <stdio.h>
 #include <string.h>
+#include <stdlib.h>
 #include <X11/keysym.h>
 
+#include <glib/gi18n.h>
 #include <gdk/gdkx.h>
-#include <gnome.h>
-#include <libgnome/gnome-util.h>
+#include <libgnome/gnome-program.h>
 
 #include <libxklavier/xklavier_config.h>
 
@@ -65,8 +66,6 @@ const char GSWITCHIT_APPLET_CONFIG_KEY_SECONDARIES[] =
 #define GSWITCHIT_KBD_CONFIG_KEY_PREFIX KEYBOARD_CONFIG_KEY_PREFIX "/kbd"
 
 const char GSWITCHIT_KBD_CONFIG_DIR[] = GSWITCHIT_KBD_CONFIG_KEY_PREFIX;
-const char GSWITCHIT_KBD_CONFIG_KEY_OVERRIDE_SETTINGS[] =
-    GSWITCHIT_KBD_CONFIG_KEY_PREFIX "/overrideSettings";
 const char GSWITCHIT_KBD_CONFIG_KEY_MODEL[] =
     GSWITCHIT_KBD_CONFIG_KEY_PREFIX "/model";
 const char GSWITCHIT_KBD_CONFIG_KEY_LAYOUTS[] =
@@ -418,6 +417,7 @@ _GSwitchItKbdConfigLoadParams (GSwitchItKbdConfig * kbdConfig,
 			g_warning ("Error reading configuration:%s\n",
 				   gerror->message);
 			g_error_free (gerror);
+			g_free (pc);
 			gerror = NULL;
 		}
 		GSwitchItKbdConfigModelSet (kbdConfig, NULL);
@@ -425,7 +425,7 @@ _GSwitchItKbdConfigLoadParams (GSwitchItKbdConfig * kbdConfig,
 		GSwitchItKbdConfigModelSet (kbdConfig, pc);
 		g_free (pc);
 	}
-	XklDebug (150, "Loaded Kbd model: [%s]\n", kbdConfig->model);
+	XklDebug (150, "Loaded Kbd model: [%s]\n", kbdConfig->model ? kbdConfig->model : "(null)");
 
 	GSwitchItKbdConfigLayoutsReset (kbdConfig);
 
@@ -478,25 +478,39 @@ _GSwitchItKbdConfigSaveParams (GSwitchItKbdConfig * kbdConfig,
 {
 	GSList *pl;
 
-	gconf_change_set_set_string (cs, paramNames[0], kbdConfig->model);
-	XklDebug (150, "Saved Kbd model: [%s]\n", kbdConfig->model);
+	if (kbdConfig->model)
+		gconf_change_set_set_string (cs, paramNames[0], kbdConfig->model);
+	else
+		gconf_change_set_unset (cs, paramNames[0]);
+	XklDebug (150, "Saved Kbd model: [%s]\n", kbdConfig->model ? kbdConfig->model : "(null)");
 
-	pl = kbdConfig->layouts;
-	while (pl != NULL) {
-		XklDebug (150, "Saved Kbd layout: [%s]\n", pl->data);
-		pl = pl->next;
+	if (kbdConfig->layouts) {
+		pl = kbdConfig->layouts;
+		while (pl != NULL) {
+			XklDebug (150, "Saved Kbd layout: [%s]\n", pl->data);
+			pl = pl->next;
+		}
+		gconf_change_set_set_list (cs,
+					   paramNames[1],
+					   GCONF_VALUE_STRING, kbdConfig->layouts);
+	} else {
+		XklDebug (150, "Saved Kbd layouts: []\n");
+		gconf_change_set_unset (cs, paramNames[1]);
 	}
-	gconf_change_set_set_list (cs,
-				   paramNames[1],
-				   GCONF_VALUE_STRING, kbdConfig->layouts);
-	pl = kbdConfig->options;
-	while (pl != NULL) {
-		XklDebug (150, "Saved Kbd option: [%s]\n", pl->data);
-		pl = pl->next;
+
+	if (kbdConfig->options) {
+		pl = kbdConfig->options;
+		while (pl != NULL) {
+			XklDebug (150, "Saved Kbd option: [%s]\n", pl->data);
+			pl = pl->next;
+		}
+		gconf_change_set_set_list (cs,
+					   paramNames[2],
+					   GCONF_VALUE_STRING, kbdConfig->options);
+	} else {
+		XklDebug (150, "Saved Kbd options: []\n");
+		gconf_change_set_unset (cs, paramNames[2]);
 	}
-	gconf_change_set_set_list (cs,
-				   paramNames[2],
-				   GCONF_VALUE_STRING, kbdConfig->options);
 }
 
 /**
@@ -636,21 +650,21 @@ GSwitchItConfigActivate (GSwitchItConfig * config)
 }
 
 void
-GSwitchItConfigLockNextGroup ()
+GSwitchItConfigLockNextGroup (void)
 {
 	int group = XklGetNextGroup ();
 	XklLockGroup (group);
 }
 
 void
-GSwitchIttConfigLockPrevGroup ()
+GSwitchItConfigLockPrevGroup (void)
 {
 	int group = XklGetPrevGroup ();
 	XklLockGroup (group);
 }
 
 void
-GSwitchItConfigRestoreGroup ()
+GSwitchItConfigRestoreGroup (void)
 {
 	int group = XklGetRestoreGroup ();
 	XklLockGroup (group);
@@ -707,26 +721,38 @@ GSwitchItKbdConfigTerm (GSwitchItKbdConfig * kbdConfig)
 }
 
 void
-GSwitchItKbdConfigLoadFromGConf (GSwitchItKbdConfig * kbdConfig)
+GSwitchItKbdConfigLoadFromGConf (GSwitchItKbdConfig * kbdConfig,
+				 GSwitchItKbdConfig * kbdConfigDefault)
 {
-	GError *gerror = NULL;
-
-	kbdConfig->overrideSettings =
-	    gconf_client_get_bool (kbdConfig->confClient,
-				   GSWITCHIT_KBD_CONFIG_KEY_OVERRIDE_SETTINGS,
-				   &gerror);
-	if (gerror != NULL) {
-		g_warning ("Error reading configuration:%s\n",
-			   gerror->message);
-		kbdConfig->overrideSettings = FALSE;
-		g_error_free (gerror);
-		gerror = NULL;
-	}
-	XklDebug (150, "Loaded Kbd override cmd: [%s]\n",
-		  kbdConfig->overrideSettings ? "true" : "false");
-
 	_GSwitchItKbdConfigLoadParams (kbdConfig,
 				       GSWITCHIT_KBD_CONFIG_ACTIVE);
+
+	if (kbdConfigDefault != NULL) {
+		GSList *pl;
+
+		if (kbdConfig->model == NULL)
+			kbdConfig->model = g_strdup (kbdConfigDefault->model);
+
+		if (kbdConfig->layouts == NULL) {
+			pl = kbdConfigDefault->layouts;
+			while (pl != NULL) {
+				kbdConfig->layouts =
+					g_slist_append (kbdConfig->layouts,
+							g_strdup (pl->data));
+				pl = pl->next;
+			}
+		}
+
+		if (kbdConfig->options == NULL) {
+			pl = kbdConfigDefault->options;
+			while (pl != NULL) {
+				kbdConfig->options =
+					g_slist_append (kbdConfig->options,
+							g_strdup (pl->data));
+				pl = pl->next;
+			}
+		}
+	}
 }
 
 void
@@ -786,11 +812,6 @@ GSwitchItKbdConfigSaveToGConf (GSwitchItKbdConfig * kbdConfig)
 	GError *gerror = NULL;
 
 	cs = gconf_change_set_new ();
-	gconf_change_set_set_bool (cs,
-				   GSWITCHIT_KBD_CONFIG_KEY_OVERRIDE_SETTINGS,
-				   kbdConfig->overrideSettings);
-	XklDebug (150, "Saved Kbd override cmd: [%s]\n",
-		  kbdConfig->overrideSettings ? "true" : "false");
 
 	_GSwitchItKbdConfigSaveParams (kbdConfig, cs,
 				       GSWITCHIT_KBD_CONFIG_ACTIVE);
@@ -835,7 +856,7 @@ GSwitchItKbdConfigModelSet (GSwitchItKbdConfig * kbdConfig,
 	if (kbdConfig->model != NULL)
 		g_free (kbdConfig->model);
 	kbdConfig->model =
-	    (modelName == NULL) ? NULL : g_strdup (modelName);
+	    (modelName == NULL || modelName[0] == '\0') ? NULL : g_strdup (modelName);
 }
 
 void
@@ -976,7 +997,7 @@ GSwitchItAppletConfigGetImagesFile (GSwitchItAppletConfig *
 	// fallback to the default value
 	if (iconInfo == NULL) {
 		iconInfo = gtk_icon_theme_lookup_icon
-		    (appletConfig->iconTheme, "applet-error", 48, 0);
+		    (appletConfig->iconTheme, "stock_dialog-error", 48, 0);
 	}
 	if (iconInfo != NULL) {
 		imageFile =
@@ -1008,7 +1029,19 @@ GSwitchItAppletConfigLoadImages (GSwitchItAppletConfig * appletConfig,
 			image =
 			    gdk_pixbuf_new_from_file (imageFile, &err);
 			if (image == NULL) {
-				gnome_error_dialog (err->message);
+				GtkWidget *dialog = gtk_message_dialog_new (NULL, 
+									    GTK_DIALOG_DESTROY_WITH_PARENT,
+									    GTK_MESSAGE_ERROR,
+									    GTK_BUTTONS_OK,
+									    _("There was an error loading an image: %s"),
+									    err->message);
+				g_signal_connect (G_OBJECT (dialog),
+						  "response",
+						  G_CALLBACK (gtk_widget_destroy), NULL);
+
+				gtk_window_set_resizable (GTK_WINDOW (dialog), FALSE);
+
+				gtk_widget_show (dialog);
 				g_error_free (err);
 			}
 			XklDebug (150,
