@@ -31,7 +31,11 @@
 #include <gconf/gconf-client.h>
 #include <panel-applet-gconf.h>
 #include <gst/gst.h>
+#ifdef HAVE_GST10
+#include <gst/interfaces/mixer.h>
+#else
 #include <gst/mixer/mixer.h>
+#endif
 
 #include "dock.h"
 
@@ -80,6 +84,7 @@ typedef struct _GnomeVolumeApplet {
 
   /* icon theme */
   GtkIconTheme *icon_theme;
+  GdkPixbuf *pix[5];
 
   /* use same object for setting tooltop */
   GtkTooltips *tooltips;
@@ -92,7 +97,7 @@ typedef struct _GnomeVolumeAppletClass {
 
 void     gnome_volume_applet_adjust_volume (GstMixer      *mixer,
 					    GstMixerTrack *track,
-					    float          volume);
+					    gdouble        volume);
 GType    gnome_volume_applet_get_type (void);
 gboolean gnome_volume_applet_setup    (GnomeVolumeApplet *applet,
 				       GList             *elements);
