@@ -10,11 +10,10 @@
 #include <gdk/gdkx.h>
 #include <gtk/gtk.h>
 #include <panel-applet.h>
+#include <panel-applet-gconf.h>
 
 #include "global.h"
 
-static GList *object_list = NULL;
-
 
 /*
   Shifts data right
@@ -88,18 +87,22 @@ load_graph_draw (LoadGraph *g)
 			g->draw_height);
 
     for (i = 0; i < g->draw_width; i++)
-		g->pos [i] = g->draw_height;
+		g->pos [i] = g->draw_height - 1;
 
     for (j = 0; j < g->n; j++)
     {
 		gdk_gc_set_foreground (g->gc, &(g->colors [j]));
 
 		for (i = 0; i < g->draw_width; i++) {
-	 	   gdk_draw_line (g->pixmap, g->gc,
-				  g->draw_width - i - 1, g->pos[i],
-			 	  g->draw_width - i - 1, g->pos[i] - g->data[i][j]);
+			if (g->data [i][j] != 0) {
+				gdk_draw_line (g->pixmap, g->gc,
+					       g->draw_width - i - 1,
+					       g->pos[i],
+					       g->draw_width - i - 1,
+					       g->pos[i] - (g->data [i][j] - 1));
 
-		    g->pos [i] -= g->data [i][j];
+				g->pos [i] -= g->data [i][j];
+			}
 		}
     }
 	
@@ -116,8 +119,6 @@ load_graph_draw (LoadGraph *g)
 static gboolean
 load_graph_update (LoadGraph *g)
 {
-    guint i;
-
     if (g->data == NULL)
 	return TRUE;
 
@@ -135,8 +136,8 @@ load_graph_update (LoadGraph *g)
 void
 load_graph_unalloc (LoadGraph *g)
 {
-    int i;
-	
+    guint i;
+
     if (!g->allocated)
 		return;
 
@@ -151,7 +152,7 @@ load_graph_unalloc (LoadGraph *g)
     g->pos = NULL;
     g->data = NULL;
     
-    g->size = panel_applet_gconf_get_int(g->applet, "size", NULL);
+    g->size = panel_applet_gconf_get_int(g->multiload->applet, "size", NULL);
     g->size = MAX (g->size, 10);
 
     if (g->pixmap) {
@@ -170,7 +171,7 @@ load_graph_unalloc (LoadGraph *g)
 static void
 load_graph_alloc (LoadGraph *g)
 {
-    int i;
+    guint i;
 
     if (g->allocated)
 		return;
@@ -244,7 +245,7 @@ static void
 load_graph_destroy (GtkWidget *widget, gpointer data_ptr)
 {
     LoadGraph *g = (LoadGraph *) data_ptr;
-	
+
     load_graph_stop (g);
     if (g->tooltips) {
     		g_object_unref (g->tooltips);
@@ -252,8 +253,14 @@ load_graph_destroy (GtkWidget *widget, gpointer data_ptr)
     }
 
     gtk_widget_destroy(widget);
-    object_list = g_list_remove (object_list, g);
-    return;
+}
+
+static gboolean
+load_graph_clicked (GtkWidget *widget, GdkEventButton *event, LoadGraph *load)
+{
+	load->multiload->last_clicked = load->id;
+
+	return FALSE;
 }
 
 static void
@@ -268,8 +275,8 @@ load_graph_load_config (LoadGraph *g)
 		
 	for (i = 0; i < g->n; i++)
 	{
-		g_snprintf(name, sizeof(name), "%s_color%d", g->name, i);
-		temp = g_strdup_printf("%s", panel_applet_gconf_get_string(g->applet, name, NULL));
+		g_snprintf(name, sizeof(name), "%s_color%u", g->name, i);
+		temp = g_strdup_printf("%s", panel_applet_gconf_get_string(g->multiload->applet, name, NULL));
 		gdk_color_parse(temp, &(g->colors[i]));
 		g_free(temp);
 	}
@@ -278,12 +285,9 @@ load_graph_load_config (LoadGraph *g)
 }
 
 LoadGraph *
-load_graph_new (PanelApplet *applet, guint n, gchar *label,
-		guint speed,
-		guint size, 
-		gboolean visible, 
-		gchar *name,
-		LoadGraphDataFunc get_data)
+load_graph_new (MultiloadApplet *ma, guint n, const gchar *label,
+		guint id, guint speed, guint size, gboolean visible, 
+		const gchar *name, LoadGraphDataFunc get_data)
 {
     LoadGraph *g;
     PanelAppletOrient orient;
@@ -293,18 +297,19 @@ load_graph_new (PanelApplet *applet, guint n, gchar *label,
     g->visible = visible;
     g->name = name;
     g->n = n;
+    g->id = id;
     g->speed  = MAX (speed, 50);
     g->size   = MAX (size, 10);
-    g->pixel_size = panel_applet_get_size (applet);
+    g->pixel_size = panel_applet_get_size (ma->applet);
     g->tooltip_update = FALSE;
     g->show_frame = TRUE;
-    g->applet = applet;
+    g->multiload = ma;
 		
     g->main_widget = gtk_vbox_new (FALSE, FALSE);
 
     g->box = gtk_vbox_new (FALSE, FALSE);
     
-    orient = panel_applet_get_orient (g->applet);
+    orient = panel_applet_get_orient (g->multiload->applet);
     switch (orient)
     {
     case PANEL_APPLET_ORIENT_UP:
@@ -352,8 +357,10 @@ load_graph_new (PanelApplet *applet, guint n, gchar *label,
     gtk_object_sink (GTK_OBJECT (g->tooltips));
 
     g->disp = gtk_drawing_area_new ();
-    gtk_widget_set_events (g->disp, GDK_EXPOSURE_MASK | GDK_ENTER_NOTIFY_MASK 
-    				    | GDK_LEAVE_NOTIFY_MASK);
+    gtk_widget_set_events (g->disp, GDK_EXPOSURE_MASK |
+				    GDK_ENTER_NOTIFY_MASK |
+    				    GDK_LEAVE_NOTIFY_MASK |
+				    GDK_BUTTON_PRESS_MASK);
 	
     g_signal_connect (G_OBJECT (g->disp), "expose_event",
 			G_CALLBACK (load_graph_expose), g);
@@ -361,13 +368,13 @@ load_graph_new (PanelApplet *applet, guint n, gchar *label,
 			G_CALLBACK (load_graph_configure), g);
     g_signal_connect (G_OBJECT(g->disp), "destroy",
 			G_CALLBACK (load_graph_destroy), g);
+    g_signal_connect (g->disp, "button-press-event",
+		        G_CALLBACK (load_graph_clicked), g);
 	
     gtk_box_pack_start (GTK_BOX (g->box), g->disp, TRUE, TRUE, 0);    
     gtk_widget_show_all(g->box);
-    object_list = g_list_append (object_list, g);
-    
+
     return g;
-    label = NULL;
 }
 
 void
